@@ -43,31 +43,40 @@ class App:
                 return None
             return 200
 
-    def run(self):
+    def run(self, cookies=None):
         """
         Main function, tries to login the user and when it succeeds, tries to download the course
         """
         try:
-            with Session() as s:
-                site = s.get(config.login_url)
-                bs_content = bs(site.content, "html.parser")
 
-                csrf = bs_content.find(
-                    'input', {'name': 'csrfToken'}).get("value")
-                loginCsrfParam = bs_content.find(
-                    "input", {"name": "loginCsrfParam"}).get("value")
-                login_data = {"session_key": self.email, "session_password": self.password,
-                              "csrfToken": csrf, "loginCsrfParam": loginCsrfParam}
+            if cookies is not None:
+                self.cookies["JSESSIONID"] = cookies.get("JSESSIONID")
+                self.cookies["li_at"] = cookies.get("li_at")
+                self.headers["Csrf-Token"] = cookies.get("JSESSIONID")
+                self.download_entire_course()
+            else:
+                with Session() as s:
+                    if not os.path.exists(f'{self.course_slug}'):
+                        os.makedirs(f'{self.course_slug}')
+                    site = s.get(config.login_url)
+                    bs_content = bs(site.content, "html.parser")
 
-                status = self.login(s, login_data)
+                    csrf = bs_content.find(
+                        'input', {'name': 'csrfToken'}).get("value")
+                    loginCsrfParam = bs_content.find(
+                        "input", {"name": "loginCsrfParam"}).get("value")
+                    login_data = {"session_key": self.email, "session_password": self.password,
+                                  "csrfToken": csrf, "loginCsrfParam": loginCsrfParam}
 
-                if status is None:
-                    print("\n")
-                    click.echo(
-                        click.style(f"Wrong credentials, try again", fg="red"))
-                    sys.exit(0)
-                else:
-                    self.download_entire_course()
+                    status = self.login(s, login_data)
+
+                    if status is None:
+                        print("\n")
+                        click.echo(
+                            click.style(f"Wrong credentials, try again", fg="red"))
+                        sys.exit(0)
+                    else:
+                        self.download_entire_course()
 
         except requests.exceptions.ConnectionError:
             print("\n")
@@ -105,6 +114,8 @@ class App:
             for chapter in chapters:
                 chapter_name = chapter["title"]
                 videos = chapter["videos"]
+                if not os.path.exists(f'{self.course_slug}/{chapter_name}'):
+                    os.makedirs(f'{self.course_slug}/{chapter_name}')
                 for video in videos:
 
                     video_name = re.sub(r'[\\/*?:"<>|]', "",
@@ -131,7 +142,7 @@ class App:
                         click.echo(
                             click.style(f"format: {self.video_format}p", fg="red"))
                         current_files = []
-                        for file in os.listdir():
+                        for file in os.listdir(f"./{self.course_slug}/{chapter_name}"):
                             if file.endswith(".mp4") and "-" in file:
                                 ff = re.split(
                                     "\d+-", file)[1].replace(".mp4", "")
@@ -150,15 +161,16 @@ class App:
                                     f"Fetching subtitles..", fg="green"))
                                 subtitle_lines = subtitles['lines']
                                 write_subtitles(
-                                    count, subtitle_lines, video_name, duration_in_ms)
-                            download_video(download_url, count, video_name)
+                                    count, subtitle_lines, video_name, self.course_slug, chapter_name, duration_in_ms)
+                            download_video(download_url, count,
+                                           video_name, chapter_name, self.course_slug)
                         else:
                             click.echo(
                                 click.style(f"skipping: " +
                                             video_name + "\n", fg="green"))
                         count += 1
             if len(exercise_files) > 0:
-                download_exercises(exercise_files)
+                download_exercises(exercise_files, self.course_slug)
             print("\n" + "Finished, start learning! :)")
 
         except Exception as e:
